@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.0.4 $
+### $Release: 0.0.5 $
 ### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
@@ -313,9 +313,21 @@ class Chdir(object):
         os.chdir(self.cwd)
 
 
-def chdir(dirname):
+def chdir(dirname, block=None):
     #return _chdir(dirname, 'chdir', 'chdir')
-    return Chdir(dirname, 'chdir', 'chdir')
+    obj = Chdir(dirname, 'chdir', 'chdir')
+    if block:
+        ex_type = ex_obj = traceback = None
+        try:
+            obj.__enter__()
+            block.__call__()
+        except Exception:
+            ex_type, ex_obj, traceback = sys.exc_info();
+        finally:
+            obj.__exit__(ex_type, ex_obj, traceback)
+            if ex_obj:
+                raise
+    return obj
 
 def cd(dirname):
     return _chdir(dirname, 'cd', 'cd')
